==> iTop-3.1.0-2-11973.zip: web/dictionaries/ui/layouts/activity-panel/hu.dictionary.itop.activity-panel.php <==
<?php
/**
 * Copyright (C) 2013-2023 Combodo SARL
 *
 * This file is part of iTop.
 *
 * iTop is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * iTop is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 */
// Activity panel
Dict::Add('HU HU', 'Hungarian', 'Magyar', array(
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Kiterjesztés',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Összecsukás',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Bezárás',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Több bejegyzés betöltése',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Minden előző bejegyzés betöltése',

	// Tabs
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Tevékenység',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Bejegyzés vázlat',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Eseménynaplók',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Naplóbejegyzések megjelenítése/elrejtése ezen a táblán',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Válassza ki, hogy mely naplók jelenjenek meg ezen a táblán',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'Állapotváltozások',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Állapotváltozások megjelenítése/elrejtése ezen a táblán',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Szerkesztések',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'A mezők szerkesztésének megjelenítése / elrejtése ezen a táblán',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Minden bejegyzés megnyitása',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Minden bejegyzés bezárása',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'A látható bejegyzésekben interakcióba lépő személyek száma',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'A látható napló(k)ban lévő üzenetek száma',

	// Compose button
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Új naplóbejegyzés összeállítása',

	// Case log entry
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Több napló mentése',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'A "mentés" gomb megnyomásával az összes szerkesztett napló bejegyzését egyszerre küldheti el.',

	// Notification entry
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Kattintson a gombra az értesítések tábla megnyitásához és további információkért.',

	// Placeholder
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'Itt nyugalom van, még nincs aktivitás.',

	// Closed cover
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Tevékenység panel',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Kattintson a gombra a tevékenység panel megnyitásához',
));

==> iTop-3.2.0-2-14758.zip: web/dictionaries/ui/layouts/activity-panel/hu.dictionary.itop.activity-panel.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('HU HU', 'Hungarian', 'Magyar', [
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Tevékenység panel',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Kattintson a gombra a tevékenység panel megnyitásához',
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Új naplóbejegyzés összeállítása',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Bezárás',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Minden előző bejegyzés betöltése',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Több bejegyzés betöltése',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'A "mentés" gomb megnyomásával az összes szerkesztett napló bejegyzését egyszerre küldheti el.',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Több napló mentése',
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'Itt nyugalom van, még nincs aktivitás.',
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Kattintson a gombra az értesítések tábla megnyitásához és további információkért.',
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Kiterjesztés',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Összecsukás',
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Tevékenység',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Bejegyzés vázlat',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Minden bejegyzés bezárása',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Minden bejegyzés megnyitása',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Szerkesztések',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'A mezők szerkesztésének megjelenítése / elrejtése ezen a táblán',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Válassza ki, hogy mely naplók jelenjenek meg ezen a táblán',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Eseménynaplók',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Naplóbejegyzések megjelenítése/elrejtése ezen a táblán',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'Állapotváltozások',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Állapotváltozások megjelenítése/elrejtése ezen a táblán',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'A látható bejegyzésekben interakcióba lépő személyek száma',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'A látható napló(k)ban lévő üzenetek száma',
]);
